@@ -5,10 +5,10 @@ require "foreman/engine/cli"
 require "foreman/export"
 require "foreman/version"
 require "shellwords"
+require "thor"
 require "yaml"
-require "foreman/vendor/thor/lib/thor"
 
-class Foreman::CLI < Foreman::Thor
+class Foreman::CLI < Thor
 
   include Foreman::Helpers
 
@@ -27,6 +27,10 @@ class Foreman::CLI < Foreman::Thor
   method_option :timestamp, :type => :boolean, :default => true, :desc => "Include timestamp in output"
 
   class << self
+    def exit_on_failure?
+      true
+    end
+
     # Hackery. Take the run method away from Thor so that we can redefine it.
     def is_thor_reserved_word?(word, type)
       return false if word == "run"
@@ -126,6 +130,13 @@ class Foreman::CLI < Foreman::Thor
         engine
       end
     end
+
+    def options
+      original_options = super
+      return original_options unless File.file?(".foreman")
+      defaults = ::YAML::load_file(".foreman") || {}
+      Thor::CoreExt::HashWithIndifferentAccess.new(defaults.merge(original_options))
+    end
   end
 
 private ######################################################################
@@ -157,11 +168,4 @@ private ######################################################################
       else "Procfile"
     end
   end
-
-  def options
-    original_options = super
-    return original_options unless File.file?(".foreman")
-    defaults = ::YAML::load_file(".foreman") || {}
-    Foreman::Thor::CoreExt::HashWithIndifferentAccess.new(defaults.merge(original_options))
-  end
 end
