@@ -1,13 +1,3 @@
-# it throws following message:
-# W, [2018-02-06T18:16:06.360071 #72025]  WARN -- :       This usage of the Code Climate Test Reporter is now deprecated. Since version
-#       1.0, we now require you to run `SimpleCov` in your test/spec helper, and then
-#       run the provided `codeclimate-test-reporter` binary separately to report your
-#       results to Code Climate.
-#
-#       More information here: https://github.com/codeclimate/ruby-test-reporter/blob/master/README.md
-# require "codeclimate-test-reporter"
-# CodeClimate::TestReporter.start
-
 require "simplecov"
 SimpleCov.start do
   add_filter "/spec/"
@@ -78,7 +68,7 @@ def fork_and_get_exitstatus(args)
 end
 
 def mock_exit(&block)
-  expect(block).to raise_error(SystemExit)
+  expect { block.call }.to raise_error(SystemExit)
 end
 
 def write_foreman_config(app)
@@ -181,7 +171,4 @@ RSpec.configure do |config|
   config.before(:each) do
     FileUtils.mkdir_p('/tmp')
   end
-  config.after(:each) do
-    FileUtils.rm_rf('/tmp')
-  end
 end
